# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`mofed`](#mofed): Manage Mellanox OFED
* [`mofed::opensm`](#mofedopensm): Manage OpenSM
* [`mofed::srp`](#mofedsrp): Manage SRP

_Private Classes_

* `mofed::config`: 
* `mofed::install`: 
* `mofed::repo`: 
* `mofed::service`: 

**Defined types**

* [`mofed::interface`](#mofedinterface): Manage IPoIB interface

## Classes

### mofed

Manage Mellanox OFED

#### Examples

##### Basic usage using local yum repo for MOFED

```puppet
class { 'mofed':
  repo_baseurl => 'http://example.com/mlnx/$releasever/3.4-2.0.0.0-rhel7.3/'
  repo_gpgkey  => 'http://example.com/mlnx/$releasever/3.4-2.0.0.0-rhel7.3/RPM-GPG-KEY-Mellanox',
}
```

#### Parameters

The following parameters are available in the `mofed` class.

##### `manage_repo`

Data type: `Boolean`

Boolean to set if MOFED repo should be managed

Default value: `true`

##### `repo_baseurl`

Data type: `Optional[String]`

The baseurl of the yumrepo resource

Default value: `undef`

##### `repo_gpgkey`

Data type: `Optional[String]`

The gpgkey of the yumrepo resource

Default value: `undef`

##### `repo_exclude`

Data type: `Optional[String]`

The exclude of the yumrepo resource

Default value: `undef`

##### `manage_packages`

Data type: `Boolean`

Boolean to determine if packages should be managed

Default value: `true`

##### `package_ensure`

Data type: `String`

The package ensure property

Default value: 'present'

##### `package_name`

Data type: `String`

The MOFED package name to install

Default value: 'mlnx-ofed-basic'

##### `extra_packages`

Data type: `Optional[Array]`

An array of additional packages to install

Default value: `undef`

##### `extra_packages_hiera_merge`

Data type: `Boolean`

Boolean that sets if extra_packages should have values merged from hiera

Default value: `false`

##### `manage_service`

Data type: `Boolean`

Boolean that determines if the openibd service should be managed

Default value: `true`

##### `restart_service`

Data type: `Boolean`

Boolean that sets of openibd should be restarted

Default value: `false`

##### `openibd_service_name`

Data type: `String`

Name of the openibd service

Default value: 'openibd'

##### `openibd_service_ensure`

Data type: `String`

openibd service ensure property

Default value: 'running'

##### `openibd_service_enable`

Data type: `Boolean`

openibd service enable property

Default value: `true`

##### `openibd_service_hasstatus`

Data type: `Boolean`

openibd service hasstatus property

Default value: `true`

##### `openibd_service_hasrestart`

Data type: `Boolean`

openibd service hasrestart property

Default value: `true`

##### `manage_config`

Data type: `Boolean`

Boolean that sets if configs should be managed

Default value: `true`

##### `openib_config_path`

Data type: `Stdlib::Absolutepath`

Path to openib.conf

Default value: '/etc/infiniband/openib.conf'

##### `openib_shellvars`

Data type: `Hash`

Hash of shellvar resources

Default value: {}

##### `interfaces`

Data type: `Hash`

Hash of mofed::interface resources

Default value: {}

### mofed::opensm

Manage OpenSM

#### Examples

##### Manage OpenSM on two specific ports

```puppet
class { 'mofed::opensm':
  ports => ['mlx4_1 1', 'mlx4_1 2'],
}
```

#### Parameters

The following parameters are available in the `mofed::opensm` class.

##### `ensure`

Data type: `Enum['present', 'absent', 'disabled']`

State of opensm.  `present` will run opensm.
`disabled` will install and configure opensm but disable services.
`absent` will remove opensm.

Default value: 'present'

##### `ports`

Data type: `Array`

Ports used by opensm

Default value: []

##### `sweep`

Data type: `Integer`

Value passsed to opensm `-s` argument.

Default value: 10

### mofed::srp

Manage SRP

#### Examples

##### Manage SRP for specific ports

```puppet
class { 'mofed::srp':
 ports => ['mlx4_1 1', 'mlx4_1 2'],
}
```

#### Parameters

The following parameters are available in the `mofed::srp` class.

##### `ensure`

Data type: `Enum['present', 'absent', 'disabled']`

State of srp.  `present` will run opensm.
`disabled` will install and configure opensm but disable services.
`absent` will remove opensm.

Default value: 'present'

##### `ports`

Data type: `Array`

Ports used by srp daemon.

Default value: []

##### `srp_daemon_config`

Data type: `Optional[Variant[String, Array]]`

Define lines in srp_daemon.conf

Default value: `undef`

##### `ib_srp_options`

Data type: `Optional[Hash[String, Variant[String,Integer], 1]]`

Options passed to ib_srp kernel module

Default value: `undef`

## Defined types

### mofed::interface

Manage IPoIB interface

#### Examples

##### Add IPoIB interface

```puppet
mofed::interface { 'ib0':
  ensure         => 'present',
  ipaddr         => '10.0.0.1',
  netmask        => '255.255.0.0',
  connected_mode => 'no',
}
```

#### Parameters

The following parameters are available in the `mofed::interface` defined type.

##### `ipaddr`

Data type: `Stdlib::Compat::Ip_address`

Required IP address.

##### `netmask`

Data type: `Stdlib::Compat::Ip_address`

Required netmask address.

##### `gateway`

Data type: `Optional[Stdlib::Compat::Ip_address]`

Gateway address.

Default value: `undef`

##### `ensure`

Data type: `Enum['present', 'absent']`

Interface ensure value.

Default value: 'present'

##### `enable`

Data type: `Boolean`

Boolean of whether to enable the interface at boot.

Default value: `true`

##### `connected_mode`

Data type: `Enum['yes', 'no']`

The value for setting interface to connected mode.

Default value: 'yes'

##### `mtu`

Data type: `Optional[Integer]`

The MTU of the interface.

Default value: `undef`

##### `bonding`

Data type: `Boolean`

If this interface is a bonding interface

Default value: `false`

##### `bonding_slaves`

Data type: `Array[String]`

Array of interfaces that should be enslaved in the bonding interface

Default value: []

##### `bonding_opts`

Data type: `String`

The bonding options to use for this bonding interface

Default value: 'mode=active-backup miimon=100'

